#include <def21489.h>
#include <cdef21489.h>


void InitSDRAM(void)
{
// SDRAM memory on EZ-KIT - MT48LC16M16A2-6A
//5.4ns @ CL = 3 ,167 MHz speed
// Parameters 
// Config - 64M x 16(16M x 16 x 4)
// Speed -        167 MHz
// CAS Latency -   3
// Row addressing - 8K(A0-A12)
// Column addressing - 512(A0-A8)
// No of Banks - 4

//tRAS - 42ns
//tRCD - 18ns
//tRP - 18ns
//tRC - 60ns( tRP + tRAS >= tRC)
//tWR - (1CLK + 6ns)/12

//For the 160 MHz case, tSDCLK = 1/160 MHz = 6.25ns 
// CAS Latency = 3
// tRCD = 18 / 6.25 = 3(2.88)
// tRP = 18 / 6.25 = 3(2.88)
// tRC = 60 / 6.25 = 10(9.6)
// tRAS = 42/ 6.25 = 7(6.72)
// tWR = (6.25 + 6)/ 12 = 2(1.02)
// fSDCLK = 160 MHz
// tREF=  64ms
// NRA = 8192

// RDIV = ((f SDCLK X t REF)/NRA) - (t RAS + t RP)
// RDIV = (((160 X 10^6 x 64 x 10^-3)/8192) - (7 + 3))
// RDIV = 1240 = 0x4D8

#define RDIV	(0x4D8)

	*pSYSCTL |= MSEN;
	
	// Mapping Bank 0 to SDRAM
	temp = *pEPCTL;
	temp = temp &~(B1SD|B2SD|B3SD);
	temp |= B0SD;
	*pEPCTL = temp;
	
	ustat1 = dm(EPCTL);
	bit set ustat1 B0SD;
	bit clr ustat1 B1SD|B2SD|B3SD;
	dm(EPCTL) = ustat1;
	
	ustat1 = RDIV; 
	bit set ustat1 SDROPT | BIT_17; // Enabling SDRAM read optimization
									// Setting the Modify to 1
	dm(SDRRC) = ustat1;

	// Programming SDRAM control register	
	ustat1 = 0;
	bit set ustat1 SDCL3|SDTRAS7|SDTRP3|SDCAW9|SDPSS|SDTWR2|SDTRCD3|SDRAW13|X16DE;
	dm(SDCTL) = ustat1;
	
	r0 = dm(0x200000);
	nop;
	nop;
	nop;
	nop;
	
}
